@@ -39,6 +39,7 @@
 #include <QtCore/QStringList>
 #include <QtCore/QSharedData>
 #include <QtCore/QSharedPointer>
+#include <QtCore/QDataStream>
 
 #include <klocale.h>
 #include <klocalizedstring.h>
@@ -942,7 +943,7 @@ KDateTime KDateTime::toUtc() const
         return *this;
     }
     if (d->dateOnly()) {
-        return KDateTime(d->date(), UTC);
+        return KDateTime(d->date(), Spec(UTC));
     }
     QDateTime udt = d->toUtc();
     if (!udt.isValid()) {
@@ -2306,12 +2307,12 @@ KDateTime KDateTime::fromString(const QString &string, const QString &format,
                     int offset = it.value().offsetAtZoneTime(qdt, &offset2);
                     QDateTime ut(qdt);
                     ut.setTimeSpec(Qt::UTC);
-                    ut.addSecs(-offset);
+                    ut = ut.addSecs(-offset);
                     if (it.value().abbreviation(ut) != zoneAbbrev) {
                         if (offset == offset2) {
                             continue;    // abbreviation doesn't apply at specified time
                         }
-                        ut.addSecs(offset - offset2);
+                        ut = ut.addSecs(offset - offset2);
                         if (it.value().abbreviation(ut) != zoneAbbrev) {
                             continue;    // abbreviation doesn't apply at specified time
                         }
@@ -2344,7 +2345,7 @@ KDateTime KDateTime::fromString(const QString &string, const QString &format,
             // For a date-only value, use the start of the day.
             QDateTime dtUTC = qdt;
             dtUTC.setTimeSpec(Qt::UTC);
-            dtUTC.addSecs(-utcOffset);
+            dtUTC = dtUTC.addSecs(-utcOffset);
             const KTimeZones::ZoneMap z = zones->zones();
             for (KTimeZones::ZoneMap::ConstIterator it = z.constBegin();  it != z.constEnd();  ++it) {
                 QList<int> offsets = it.value().utcOffsets();
